summaryrefslogtreecommitdiff
path: root/inotail.h
diff options
context:
space:
mode:
Diffstat (limited to 'inotail.h')
-rw-r--r--inotail.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/inotail.h b/inotail.h
index 882d78d..2fd2cc4 100644
--- a/inotail.h
+++ b/inotail.h
@@ -9,11 +9,13 @@ enum { M_LINES, M_BYTES };
/* Every tailed file is represented as a file_struct */
struct file_struct {
- char *name; /* Name of file (or '-' for stdin) */
- int fd; /* File descriptor (or -1 if file is not open */
- off_t st_size; /* File size */
+ char *name; /* Name of file (or '-' for stdin) */
+ int fd; /* File descriptor (or -1 if file is not open */
+ off_t st_size; /* File size */
- int i_watch; /* Inotify watch associated with file_struct */
+ unsigned ignore; /* Wheter to ignore the file in further processing */
+
+ int i_watch; /* Inotify watch associated with file_struct */
};
#ifdef DEBUG